R/RcppExports.R
corr_pfs_os.RdComputes the correlation between PFS and OS given the correlation between PD and OS.
corr_pfs_os(
piecewiseSurvivalTime = 0L,
hazard_pfs = NA_real_,
hazard_os = NA_real_,
rho_pd_os = NA_real_
)A vector that specifies the starting time of
piecewise exponential survival time intervals. Must start with 0, e.g.,
c(0, 6) breaks the time axis into 2 event intervals:
\([0, 6)\) and \([6, \infty)\).
Defaults to 0 for exponential distribution.
A scalar or numeric vector specifying the hazard(s) for PFS based on a piecewise exponential distribution.
A scalar or numeric vector specifying the hazard(s) for overall survival (OS) based on a piecewise exponential distribution.
A numeric value specifying the correlation between PD and OS times.
The estimated correlation between PFS and OS.
This function first determines the piecewise exponential distribution for PD such that the implied survival function for PFS time, \(T_{\text{pfs}} = \min(T_{\text{pd}}, T_{\text{os}})\), closely matches the specified piecewise exponential distribution for PFS with hazard vector \(\lambda_{\text{pfs}}\). Then, it calculates the correlation between PFS and OS times based on the derived piecewise exponential distribution for PD and the given piecewise exponential distribution for OS.