Obtains the default weight matrix for all intersection hypotheses, assigning equal weights to the elementary hypotheses within each intersection hypothesis.

fDefaultWgtmat(m)

Arguments

m

The number of elementary hypotheses.

Value

A list with the following components:

  • inthyp: The indicator matrix for the intersection hypotheses.

  • wgtmat: The default weight matrix for the elementary hypotheses.

Author

Kaifeng Lu, kaifenglu@gmail.com

Examples


fDefaultWgtmat(3)
#> $inthyp
#>      [,1] [,2] [,3]
#> [1,]    1    1    1
#> [2,]    1    1    0
#> [3,]    1    0    1
#> [4,]    1    0    0
#> [5,]    0    1    1
#> [6,]    0    1    0
#> [7,]    0    0    1
#> 
#> $wgtmat
#>           [,1]      [,2]      [,3]
#> [1,] 0.3333333 0.3333333 0.3333333
#> [2,] 0.5000000 0.5000000 0.0000000
#> [3,] 0.5000000 0.0000000 0.5000000
#> [4,] 1.0000000 0.0000000 0.0000000
#> [5,] 0.0000000 0.5000000 0.5000000
#> [6,] 0.0000000 1.0000000 0.0000000
#> [7,] 0.0000000 0.0000000 1.0000000
#>