Obtains the adjusted p-values for graphical approaches using weighted Simes tests.
fadjpsim(p, wgtmat = NULL, family = NULL)The raw p-values for elementary hypotheses.
A list containing the weight matrix and the indicator matrix
for intersection hypotheses. If NULL, equal weights are assigned
within each intersection hypothesis.
The matrix of family indicators for elementary hypotheses. Defaults to one family containing all elementary hypotheses.
A list with the following components:
inthyp: The indicator matrix for the intersection hypotheses.
pinter: The local p-values for the intersection hypotheses.
padj: The adjusted p-values for the elementary hypotheses.
Frank Bretz, Martin Posch, Ekkehard Glimm, Florian Klinglmueller, Willi Maurer, and Kornelius Rohmeyer. Graphical approach for multiple comparison procedures using weighted Bonferroni, Simes, or parameter tests. Biometrical Journal. 2011; 53:894-913.
Kaifeng Lu. Graphical approaches using a Bonferroni mixture of weighted Simes tests. Statistics in Medicine. 2016; 35:4041-4055.
pvalues <- matrix(c(0.01,0.005,0.015,0.022, 0.02,0.015,0.010,0.023),
nrow=2, ncol=4, byrow=TRUE)
w <- c(0.5,0.5,0,0)
G <- matrix(c(0,0,1,0,0,0,0,1,0,1,0,0,1,0,0,0),
nrow=4, ncol=4, byrow=TRUE)
wgtmat <- fwgtmat(w,G)
family <- matrix(c(1,1,0,0,0,0,1,1), nrow=2, ncol=4, byrow=TRUE)
fadjpsim(pvalues, wgtmat, family)
#> $inthyp
#> [,1] [,2] [,3] [,4]
#> [1,] 1 1 1 1
#> [2,] 1 1 1 0
#> [3,] 1 1 0 1
#> [4,] 1 1 0 0
#> [5,] 1 0 1 1
#> [6,] 1 0 1 0
#> [7,] 1 0 0 1
#> [8,] 1 0 0 0
#> [9,] 0 1 1 1
#> [10,] 0 1 1 0
#> [11,] 0 1 0 1
#> [12,] 0 1 0 0
#> [13,] 0 0 1 1
#> [14,] 0 0 1 0
#> [15,] 0 0 0 1
#>
#> $pinter
#> [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
#> [1,] 0.01 0.01 0.01 0.01 0.02 0.01 0.02 0.01 0.01 0.01 0.005 0.005 0.022 0.015
#> [2,] 0.02 0.02 0.02 0.02 0.04 0.02 0.04 0.02 0.02 0.02 0.015 0.015 0.020 0.010
#> [,15]
#> [1,] 0.022
#> [2,] 0.023
#>
#> $padj
#> [,1] [,2] [,3] [,4]
#> [1,] 0.02 0.01 0.022 0.022
#> [2,] 0.04 0.02 0.040 0.040
#>