Obtains the indicator matrix for all intersection hypotheses formed from a given number of elementary hypotheses, matching the row order used by fwgtmat and fDefaultWgtmat.

finthyp(m)

Arguments

m

The number of elementary hypotheses.

Value

The \((2^m-1) \times m\) indicator matrix for the intersection hypotheses, with row 1 the global intersection (all hypotheses active) and the last row the singleton {m}.

Author

Kaifeng Lu, kaifenglu@gmail.com

Examples


finthyp(3)
#>      [,1] [,2] [,3]
#> [1,]    1    1    1
#> [2,]    1    1    0
#> [3,]    1    0    1
#> [4,]    1    0    0
#> [5,]    0    1    1
#> [6,]    0    1    0
#> [7,]    0    0    1