Converts a decimal to a fraction based on the algorithm from http://stackoverflow.com/a/5128558/221955.
Author
Kaifeng Lu, kaifenglu@gmail.com
Converts a decimal to a fraction based on the algorithm from http://stackoverflow.com/a/5128558/221955.
Kaifeng Lu, kaifenglu@gmail.com