R/multiplicity.R
fstp2seq.RdObtains the adjusted p-values for the stepwise gatekeeping procedures for multiplicity problems involving two sequences of hypotheses.
fstp2seq(p, gamma, test = "hochberg", retest = TRUE)The raw p-values for elementary hypotheses.
The truncation parameters for each family. The truncation parameter for the last family is automatically set to 1.
The component multiple testing procedure. It is either "Holm" or "Hochberg", and it defaults to "Hochberg".
Whether to allow retesting. It defaults to TRUE.
A matrix of adjusted p-values.