Obtains the p-value, conservative point estimate, and confidence interval after the end of an adaptive multi-arm multi-stage trial.
getADCI_multiarm(
M = NA_integer_,
r = 1,
corr_known = TRUE,
L = NA_integer_,
zL = NA_real_,
IMax = NA_real_,
kMax = NA_integer_,
informationRates = NA_real_,
efficacyStopping = NA_integer_,
criticalValues = NULL,
alpha = 0.25,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA_real_,
spendingTime = NA_real_,
MullerSchafer = FALSE,
MNew = NA_integer_,
selected = NA_integer_,
rNew = 1,
Lc = NA_integer_,
zLc = NA_real_,
INew = NA_real_,
informationRatesNew = NA_real_,
efficacyStoppingNew = NA_integer_,
typeAlphaSpendingNew = "sfOF",
parameterAlphaSpendingNew = NA_real_,
spendingTimeNew = NA_real_,
nthreads = 0
)A data frame with the following variables:
level: Number of elementary hypotheses considered for multiplicity.
index: The treatment arm with max Z among the active arms.
pvalue: p-value for rejecting the null hypothesis.
thetahat: Point estimate of the parameter.
cilevel: Confidence interval level.
lower: Lower bound of confidence interval.
upper: Upper bound of confidence interval.
Number of active treatment arms in the primary trial.
Randomization ratio of each active arm to the common control in the primary trial.
Logical. If TRUE, the correlation between Wald
statistics is derived from the randomization ratio \(r\)
as \(r / (r + 1)\). If FALSE, a conservative correlation of
0 is assumed.
The interim adaptation look of the primary trial.
The z-test statistics at the interim adaptation look of the primary trial.
Maximum information for any active arm versus the common control for the primary trial. Must be provided.
The maximum number of stages of the primary trial.
The information rates of the primary trial.
Indicators of whether efficacy stopping is
allowed at each stage of the primary trial. Defaults to TRUE
if left unspecified.
The matrix of by-level upper boundaries on the
max z-test statistic scale for efficacy stopping up to look L
for the primary trial.
The first column is for level M, the second column is for
level M - 1, and so on, with the last column for level 1.
If left unspecified, the critical values will be computed based
on the specified alpha spending function.
The significance level of the primary trial. Defaults to 0.025.
The type of alpha spending for the primary
trial. One of the following:
"OF" for O'Brien-Fleming boundaries,
"P" for Pocock boundaries,
"WT" for Wang & Tsiatis boundaries,
"sfOF" for O'Brien-Fleming type spending function,
"sfP" for Pocock type spending function,
"sfKD" for Kim & DeMets spending function,
"sfHSD" for Hwang, Shi & DeCani spending function, and
"none" for no early efficacy stopping.
Defaults to "sfOF".
The parameter value of alpha spending
for the primary trial. Corresponds to \(\Delta\) for "WT",
\(\rho\) for "sfKD", and \(\gamma\) for "sfHSD".
The error spending time of the primary trial.
Defaults to missing, in which case, it is the same as
informationRates.
Whether to use the Muller and Schafer (2001) method for trial adaptation.
The number of active treatment arms in the secondary trial.
The indices of the selected treatment arms for the
secondary trial among the M active arms in the primary trial.
The randomization ratio of each active arm to the common control in the secondary trial.
The termination look of the integrated trial.
The z-test statistics at the termination look of the integrated trial.
The maximum information for any active arm versus the common control in the secondary trial.
The spacing of looks of the secondary trial.
The indicators of whether efficacy stopping is
allowed at each look of the secondary trial.
Defaults to TRUE if left unspecified.
The type of alpha spending for the secondary
trial. One of the following:
"OF" for O'Brien-Fleming boundaries,
"sfOF" for O'Brien-Fleming type spending function,
"sfP" for Pocock type spending function,
"sfKD" for Kim & DeMets spending function,
"sfHSD" for Hwang, Shi & DeCani spending function, and
"none" for no early efficacy stopping.
Defaults to "sfOF".
The parameter value of alpha spending
for the secondary trial. Corresponds to
\(\rho\) for "sfKD", and \(\gamma\) for "sfHSD".
The error spending time of the secondary trial.
Defaults to missing, in which case, it is
the same as informationRatesNew.
The number of threads to use (0 leaves the RcppParallel setting unchanged).
Kaifeng Lu, kaifenglu@gmail.com
If typeAlphaSpendingNew is "OF" or "none", then
informationRatesNew, efficacyStoppingNew, and
spendingTimeNew must be of full length kNew, and
informationRatesNew and spendingTimeNew must end with 1.
Ping Gao, Yingqiu Li. Adaptive multiple comparison sequential design (AMCSD) for clinical trials. Journal of Biopharmaceutical Statistics, 2024, 34(3), 424-440.
getADCI_multiarm(
M = 2, r = 1, corr_known = FALSE, L = 1, zL = c(2.075, 2.264),
IMax = 300 / 4, kMax = 2, informationRates = c(0.5, 1),
alpha = 0.025, typeAlphaSpending = "sfOF",
MNew = 1, selected = 2, rNew = 1,
Lc = 2, zLc = 1.667, INew = 374 / 4, nthreads = 1)
Run the code above in your browser using DataLab