getAccrualDurationFromN: Accrual Duration to Enroll Target Number of Subjects

View source: R/RcppExports.R

getAccrualDurationFromNR Documentation

Accrual Duration to Enroll Target Number of Subjects

Description

Obtains the accrual duration to enroll the target number of subjects.

Usage

getAccrualDurationFromN(nsubjects, accrualTime, accrualIntensity)

Arguments

nsubjects

The vector of target number of subjects.

accrualTime

A vector that specifies the starting time of piecewise Poisson enrollment time intervals. Must start with 0, e.g., c(0, 3) breaks the time axis into 2 accrual intervals: [0, 3) and [3, \infty).

accrualIntensity

A vector of accrual intensities. One for each accrual time interval.

Value

A vector of accrual durations.

Author(s)

Kaifeng Lu, kaifenglu@gmail.com

Examples

getAccrualDurationFromN(nsubjects = c(20, 150), accrualTime = c(0, 3),
                        accrualIntensity = c(10, 20))


lrstat documentation built on May 13, 2026, 9:06 a.m.