R/getDesignMeans.R
getDesignRepeatedANOVAContrast.RdObtains the power and sample size for a single contrast in one-way repeated measures analysis of variance.
getDesignRepeatedANOVAContrast(
beta = NA_real_,
n = NA_real_,
ngroups = 2,
means = NA_real_,
stDev = 1,
corr = 0,
contrast = NA_real_,
meanContrastH0 = 0,
rounding = TRUE,
alpha = 0.025
)The type II error.
The total sample size.
The number of treatment groups.
The treatment group means.
The total standard deviation.
The correlation among the repeated measures.
The coefficients for the single contrast.
The mean of the contrast under the null hypothesis.
Whether to round up sample size. Defaults to 1 for sample size rounding.
The one-sided significance level. Defaults to 0.025.
An S3 class designRepeatedANOVAContrast object with
the following components:
power: The power to reject the null hypothesis for the
treatment contrast.
alpha: The one-sided significance level.
n: The number of subjects.
ngroups: The number of treatment groups.
means: The treatment group means.
stDev: The total standard deviation.
corr: The correlation among the repeated measures.
contrast: The coefficients for the single contrast.
meanContrastH0: The mean of the contrast under the null
hypothesis.
meanContrast: The mean of the contrast under the alternative
hypothesis.
effectsize: The effect size.
rounding: Whether to round up sample size.