R/RcppExports.R
getNFromNeventsAndFollowup.RdObtains the accrual duration and sample size to reach the target number of events given follow-up time.
getNFromNeventsAndFollowup(
nevents = NA_real_,
allocationRatioPlanned = 1,
accrualTime = 0L,
accrualIntensity = NA_real_,
piecewiseSurvivalTime = 0L,
stratumFraction = 1L,
lambda1 = NA_real_,
lambda2 = NA_real_,
gamma1 = 0L,
gamma2 = 0L,
followupTime = NA_real_,
fixedFollowup = FALSE
)The target number of events.
Allocation ratio for the active treatment versus control. Defaults to 1 for equal randomization.
A vector that specifies the starting time of
piecewise Poisson enrollment time intervals. Must start with 0, e.g.,
c(0, 3) breaks the time axis into 2 accrual intervals:
\([0, 3)\) and \([3, \infty)\).
A vector of accrual intensities. One for each accrual time interval.
A vector that specifies the starting time of
piecewise exponential survival time intervals. Must start with 0, e.g.,
c(0, 6) breaks the time axis into 2 event intervals:
\([0, 6)\) and \([6, \infty)\).
Defaults to 0 for exponential distribution.
A vector of stratum fractions that sum to 1. Defaults to 1 for no stratification.
A vector of hazard rates for the event in each analysis time interval by stratum for the active treatment group.
A vector of hazard rates for the event in each analysis time interval by stratum for the control group.
The hazard rate for exponential dropout, a vector of hazard rates for piecewise exponential dropout applicable for all strata, or a vector of hazard rates for dropout in each analysis time interval by stratum for the active treatment group.
The hazard rate for exponential dropout, a vector of hazard rates for piecewise exponential dropout applicable for all strata, or a vector of hazard rates for dropout in each analysis time interval by stratum for the control group.
Follow-up time for the last enrolled subjects. Must be provided.
Whether a fixed follow-up design is used.
Defaults to FALSE for variable follow-up.
A data frame of the following variables:
nevents: The target number of events.
fixedFollowup: Whether a fixed follow-up design is used.
accrualDuration: The accrual duration.
subjects: The total number of subjects.
followupTime: The follow-up time for the last enrolled subject.
studyDuration: The study duration.
# Piecewise accrual, piecewise exponential survivals, and 5% dropout by
# the end of 1 year.
getNFromNeventsAndFollowup(
nevents = 80, allocationRatioPlanned = 1,
accrualTime = seq(0, 8),
accrualIntensity = 26/9*seq(1, 9),
piecewiseSurvivalTime = c(0, 6),
lambda1 = c(0.0533, 0.0309),
lambda2 = c(0.0533, 0.0533),
gamma1 = -log(1-0.05)/12,
gamma2 = -log(1-0.05)/12,
followupTime = 18,
fixedFollowup = FALSE)
#> nevents fixedFollowup accrualDuration subjects followupTime studyDuration
#> 1 80 FALSE 9.221746 135.7654 18 27.22175