R/RcppExports.R
mnRiskRatioCI.RdObtains the Miettinen-Nurminen score confidence interval for two-sample risk ratio possibly with stratification.
mnRiskRatioCI(n1, y1, n2, y2, cilevel = 0.95)A list with two components:
data A data frame containing the input sample size
and number of responses for each treatment group.
It has the following variables:
n1: The sample size for the active treatment group.
y1: The number of responses for the active treatment group.
n2: The sample size for the control group.
y2: The number of responses for the control group.
estimates: A data frame containing the point estimate
and confidence interval for risk ratio. It has the following
variables:
scale: The scale of treatment effect.
estimate: The point estimate.
lower: The lower limit of the confidence interval.
upper: The upper limit of the confidence interval.
cilevel: The confidence interval level.
The Mantel-Haenszel sample size weights are used for stratified samples.