R/RcppExports.R
mtpwexp.RdObtains the mean and variance from a truncated piecewise exponential distribution.
mtpwexp(piecewiseSurvivalTime = 0L, lambda = NA_real_, lowerBound = 0)A vector that specifies the starting time of
piecewise exponential survival time intervals. Must start with 0, e.g.,
c(0, 6) breaks the time axis into 2 event intervals:
\([0, 6)\) and \([6, \infty)\).
Defaults to 0 for exponential distribution.
A vector of hazard rates for the event. One for each analysis time interval.
The left truncation time point for the survival time. Defaults to 0 for no truncation.
A list with two components, one for the mean, and the other for the variance of the truncated piecewise exponential distribution.