plot.assess_phregr: Plot method for assess_phregr objects

View source: R/plots.R

plot.assess_phregrR Documentation

Plot method for assess_phregr objects

Description

Generate line plots of observed and simulated paths of standardized score processes of a Cox model.

Usage

## S3 method for class 'assess_phregr'
plot(x, nsim = 20, ...)

Arguments

x

An object of class assess_phregr.

nsim

The number of simulation samples used in the plot.

...

Ensures that all arguments starting from "..." are named.

Value

A list of ggplot2 objects for the line plots, one for each covariate.

Author(s)

Kaifeng Lu, kaifenglu@gmail.com


lrstat documentation built on May 13, 2026, 9:06 a.m.