print.designTwoMultinom: Print Power and Sample Size Results for Difference in...

View source: R/prints_getDesignProportions.R

print.designTwoMultinomR Documentation

Print Power and Sample Size Results for Difference in Two-Sample Multinomial Response

Description

Prints the power and sample size for difference in two-sample multinomial response.

Usage

## S3 method for class 'designTwoMultinom'
print(x, ...)

Arguments

x

The designTwoMultinom object to print.

...

Ensures that all arguments starting from "..." are named.

Value

A tabular printout of the design elements.

Author(s)

Kaifeng Lu, kaifenglu@gmail.com


lrstat documentation built on Aug. 25, 2026, 5:07 p.m.