print.lrsim_bmTrtSel: Print Simulation Results for Phase 2/3 Seamless Design with...

View source: R/prints.R

print.lrsim_bmTrtSelR Documentation

Print Simulation Results for Phase 2/3 Seamless Design with Biomarker-Based Treatment Selection

Description

Prints the summary statistics from simulation for a seamless phase II/III design that selects one dose at the end of phase II based on a short-term efficacy endpoint and a short-term toxicity endpoint, and compares the testing procedures available for the confirmatory analysis.

Usage

## S3 method for class 'lrsim_bmTrtSel'
print(x, ...)

Arguments

x

The lrsim_bmTrtSel object to print.

...

Ensures that all arguments starting from "..." are named.

Value

A tabular printout of the summary statistics from simulation runs.

Author(s)

Kaifeng Lu, kaifenglu@gmail.com


lrstat documentation built on Aug. 25, 2026, 5:07 p.m.