Learn R Programming

lrstat (version 0.3.3)

print.lrsim_seamless: Print Simulation Results for Phase 2/3 Seamless Design for Logrank Test

Description

Prints the summary statistics from simulation for logrank test.

Usage

# S3 method for lrsim_seamless
print(x, ...)

Value

A tabular printout of the summary statistics from simulation runs.

Arguments

x

The lrsim_seamless object to print.

...

Ensures that all arguments starting from "..." are named.

Author

Kaifeng Lu, kaifenglu@gmail.com