Learn R Programming

lrstat (version 0.3.3)

print.rdsim_seamless: Print Simulation Results for Phase 2/3 Seamless Design for Risk Difference

Description

Prints the summary statistics from simulation for risk difference.

Usage

# S3 method for rdsim_seamless
print(x, ...)

Value

A tabular printout of the summary statistics from simulation runs.

Arguments

x

The rdsim_seamless object to print.

...

Ensures that all arguments starting from "..." are named.

Author

Kaifeng Lu, kaifenglu@gmail.com