Obtains the quantile of a truncated piecewise exponential distribution.
qtpwexp(
p,
piecewiseSurvivalTime = 0,
lambda = 0.0578,
lowerBound = 0,
lower.tail = TRUE,
log.p = FALSE
)The vector of probabilities.
A vector that specifies the starting time of
piecewise exponential survival time intervals. Must start with 0, e.g.,
c(0, 6) breaks the time axis into 2 event intervals:
\([0, 6)\) and \([6, \infty)\).
Defaults to 0 for exponential distribution.
A vector of hazard rates for the event. One for each analysis time interval.
The left truncation time point for the survival time. Defaults to 0 for no truncation.
Logical; if TRUE (default), probabilities are P(X <= x), otherwise, P(X > x).
Logical; if TRUE, probabilities p are given as log(p).
The quantile q such that P(X > q | X > lowerBound) = 1 - p.