R/RcppExports.R
remlOddsRatio.RdObtains the restricted maximum likelihood estimates of individual proportions with specified odds ratio.
remlOddsRatio(n1, y1, n2, y2, oddsRatioH0 = 1)A vector of the restricted maximum likelihood estimates of the response probabilities for the two treatment groups.
remlOddsRatio(n1 = 10, y1 = 4, n2 = 20, y2 = 2, oddsRatioH0 = 1.25)
#> [1] 0.2242871 0.1878564