R/RcppExports.R
remlRateDiff.RdObtains the restricted maximum likelihood estimates of individual proportions with specified rate difference.
remlRateDiff(t1, y1, t2, y2, rateDiffH0 = 0)A vector of the restricted maximum likelihood estimates of the incidence rates for the two treatment groups.
remlRateDiff(t1 = 10, y1 = 4, t2 = 20, y2 = 2, rateDiffH0 = 0.1)
#> [1] 0.2457427 0.1457427