R/RcppExports.R
remlRateRatio.RdObtains the restricted maximum likelihood estimates of individual proportions with specified rate ratio.
remlRateRatio(t1, y1, t2, y2, rateRatioH0 = 1)A vector of the restricted maximum likelihood estimates of the incidence rates for the two treatment groups.
remlRateRatio(t1 = 10, y1 = 4, t2 = 20, y2 = 2, rateRatioH0 = 1.1)
#> [1] 0.2129032 0.1935484