R/RcppExports.R
remlRiskDiff.RdObtains the restricted maximum likelihood estimates of individual proportions with specified risk difference.
remlRiskDiff(n1, y1, n2, y2, riskDiffH0 = 0)A vector of the restricted maximum likelihood estimates of the response probabilities for the two treatment groups.
remlRiskDiff(n1 = 10, y1 = 4, n2 = 20, y2 = 0, riskDiffH0 = 0.1)
#> [1] 0.14332071 0.04332071