R/RcppExports.R
remlRiskRatio.RdObtains the restricted maximum likelihood estimates of individual proportions with specified risk ratio.
remlRiskRatio(n1, y1, n2, y2, riskRatioH0 = 1)A vector of the restricted maximum likelihood estimates of the response probabilities for the two treatment groups.
remlRiskRatio(n1 = 10, y1 = 4, n2 = 20, y2 = 2, riskRatioH0 = 1.2)
#> [1] 0.2281748 0.1901457