- beta
The type II error.
- kMax
The maximum number of stages.
- informationRates
The information rates.
Defaults to (1:kMax) / kMax if left unspecified.
- criticalValues
Upper boundaries on the z-test statistic scale
for stopping for efficacy.
- alpha
The significance level for each of the two one-sided
tests. Defaults to 0.05.
- typeAlphaSpending
The type of alpha spending. One of the following:
"OF" for O'Brien-Fleming boundaries,
"P" for Pocock boundaries,
"WT" for Wang & Tsiatis boundaries,
"sfOF" for O'Brien-Fleming type spending function,
"sfP" for Pocock type spending function,
"sfKD" for Kim & DeMets spending function,
"sfHSD" for Hwang, Shi & DeCani spending function,
"user" for user defined spending, and
"none" for no early efficacy stopping.
Defaults to "sfOF".
- parameterAlphaSpending
The parameter value for the alpha spending.
Corresponds to \(\Delta\) for "WT", \(\rho\) for "sfKD",
and \(\gamma\) for "sfHSD".
- userAlphaSpending
The user defined alpha spending. Cumulative alpha
spent up to each stage.
- milestone
The milestone time at which to calculate the
restricted mean survival time.
- rmstDiffLower
The lower equivalence limit of restricted mean
survival time difference.
- rmstDiffUpper
The upper equivalence limit of restricted mean
survival time difference.
- allocationRatioPlanned
Allocation ratio for the active treatment
versus control. Defaults to 1 for equal randomization.
- accrualTime
A vector that specifies the starting time of
piecewise Poisson enrollment time intervals. Must start with 0, e.g.,
c(0, 3) breaks the time axis into 2 accrual intervals:
\([0, 3)\) and \([3, \infty)\).
- accrualIntensity
A vector of accrual intensities. One for
each accrual time interval.
- piecewiseSurvivalTime
A vector that specifies the starting time of
piecewise exponential survival time intervals. Must start with 0, e.g.,
c(0, 6) breaks the time axis into 2 event intervals:
\([0, 6)\) and \([6, \infty)\).
Defaults to 0 for exponential distribution.
- stratumFraction
A vector of stratum fractions that sum to 1.
Defaults to 1 for no stratification.
- lambda1
A vector of hazard rates for the event in each analysis
time interval by stratum for the active treatment group.
- lambda2
A vector of hazard rates for the event in each analysis
time interval by stratum for the control group.
- gamma1
The hazard rate for exponential dropout, a vector of hazard
rates for piecewise exponential dropout applicable for all strata, or a
vector of hazard rates for dropout in each analysis time interval
by stratum for the active treatment group.
- gamma2
The hazard rate for exponential dropout, a vector of hazard
rates for piecewise exponential dropout applicable for all strata, or a
vector of hazard rates for dropout in each analysis time interval
by stratum for the control group.
- accrualDuration
Duration of the enrollment period.
- followupTime
Follow-up time for the last enrolled subject.
- fixedFollowup
Whether a fixed follow-up design is used.
Defaults to FALSE for variable follow-up.
- spendingTime
A vector of length kMax for the error spending
time at each analysis. Defaults to missing, in which case, it is the
same as informationRates.
- rounding
Whether to round up sample size.
Defaults to 1 for sample size rounding.