Obtains the restricted mean survival time over an interval.
Arguments
- t1
Lower bound of the analysis time interval.
- t2
Upper bound of the analysis time interval.
- piecewiseSurvivalTime
A vector that specifies the starting time of piecewise exponential survival time intervals. Must start with 0, e.g.,
c(0, 6)breaks the time axis into 2 event intervals: \([0, 6)\) and \([6, \infty)\). Defaults to 0 for exponential distribution.- lambda
A vector of hazard rates for the event. One for each analysis time interval.
Author
Kaifeng Lu, kaifenglu@gmail.com