R/utilities.R
rtpwexp.RdObtains random samples from a truncated piecewise exponential distribution.
rtpwexp(n, piecewiseSurvivalTime = 0, lambda = 0.0578, lowerBound = 0)The number of observations.
A vector that specifies the starting time of
piecewise exponential survival time intervals. Must start with 0, e.g.,
c(0, 6) breaks the time axis into 2 event intervals:
\([0, 6)\) and \([6, \infty)\).
Defaults to 0 for exponential distribution.
A vector of hazard rates for the event. One for each analysis time interval.
The left truncation time point for the survival time. Defaults to 0 for no truncation.
The random numbers from truncated piecewise exponential distribution.