Obtains the sample size given power for exact unconditional test of equivalence in risk ratio.
samplesizeRiskRatioExactEquiv(
beta = NA_real_,
riskRatioLower = NA_real_,
riskRatioUpper = NA_real_,
pi1 = NA_real_,
pi2 = NA_real_,
allocationRatioPlanned = 1,
alpha = 0.05,
calculateAttainedAlpha = TRUE,
max_n_search = 1000L,
window = 10L
)A data frame with the following variables:
alpha: The specified significance level for each of the two
one-sided tests.
attainedAlpha: The attained significance level.
power: The power.
n: The sample size.
riskRatioLower: The lower equivalence limit of risk ratio.
riskRatioUpper: The upper equivalence limit of risk ratio.
pi1: The assumed probability for the active treatment group.
pi2: The assumed probability for the control group.
riskRatio: The risk ratio.
allocationRatioPlanned: Allocation ratio for the active
treatment versus control.
zstatRiskRatioLower: The efficacy boundaries on the
z-test statistic scale for the one-sided null hypothesis on the
lower equivalence limit.
zstatRiskRatioUpper: The efficacy boundaries on the
z-test statistic scale for the one-sided null hypothesis on the
upper equivalence limit.
The type II error.
The lower equivalence limit of risk ratio.
The upper equivalence limit of risk ratio.
The assumed probability for the active treatment group.
The assumed probability for the control group.
Allocation ratio for the active treatment versus control. Defaults to 1 for equal randomization.
The significance level for each of the two one-sided tests. Defaults to 0.05.
Whether to calculate the attained alpha.
The maximum sample size to search up to. If no sample size up to this value satisfies the windowed power criterion, an error is thrown.
The number of consecutive sample sizes that must all satisfy the power criterion to confirm the found sample size. This is to mitigate non-monotonicity of power in sample size for the exact test.
Kaifeng Lu, kaifenglu@gmail.com
samplesizeRiskRatioExactEquiv(
beta = 0.2, riskRatioLower = 0.7, riskRatioUpper = 1/0.7,
pi1 = 0.95, pi2 = 0.95, alpha = 0.05)
Run the code above in your browser using DataLab