- betaNew
The type II error for the secondary trial.
- INew
The maximum information for any active arm versus the common
control in the secondary trial. Either
betaNew or INew should be provided, while the other
must be missing.
- M
Number of active treatment arms in the primary trial.
- r
Randomization ratio of each active arm to the common control
in the primary trial.
- corr_known
Logical. If TRUE, the correlation between Wald
statistics is derived from the randomization ratio \(r\)
as \(r / (r + 1)\). If FALSE, a conservative correlation of
0 is assumed.
- L
The interim adaptation look of the primary trial.
- zL
The z-test statistics at the interim adaptation look of
the primary trial.
- theta
A vector of length \(M\) representing the assumed treatment
effects for each active arm versus the common control. The global null
is \(\theta_i = 0\) for all \(i\), and alternatives are one-sided:
\(\theta_i > 0\) for at least one \(i = 1, \ldots, M\).
- IMax
Maximum information for any active arm versus the common
control for the primary trial. Must be provided.
- kMax
The maximum number of stages of the primary trial.
- informationRates
The information rates of the primary trial.
- efficacyStopping
Indicators of whether efficacy stopping is
allowed at each stage of the primary trial. Defaults to TRUE
if left unspecified.
- futilityStopping
Indicators of whether futility stopping is
allowed at each stage of the primary trial.
- criticalValues
The matrix of by-level upper boundaries on the
max z-test statistic scale for efficacy stopping for the primary trial.
The first column is for level M, the second column is for
level M - 1, and so on, with the last column for level 1.
If left unspecified, the critical values will be computed based
on the specified alpha spending function.
- alpha
The significance level of the primary trial.
Defaults to 0.025.
- typeAlphaSpending
The type of alpha spending for the primary
trial. One of the following:
"OF" for O'Brien-Fleming boundaries,
"P" for Pocock boundaries,
"WT" for Wang & Tsiatis boundaries,
"sfOF" for O'Brien-Fleming type spending function,
"sfP" for Pocock type spending function,
"sfKD" for Kim & DeMets spending function,
"sfHSD" for Hwang, Shi & DeCani spending function,
"user" for user defined spending, and
"none" for no early efficacy stopping.
Defaults to "sfOF".
- parameterAlphaSpending
The parameter value of alpha spending
for the primary trial. Corresponds to \(\Delta\) for "WT",
\(\rho\) for "sfKD", and \(\gamma\) for "sfHSD".
- userAlphaSpending
The user-defined alpha spending for the
primary trial. Represents the cumulative alpha spent up to each stage.
- futilityBounds
The futility boundaries on the max-z statistic
scale for the primary trial. Defaults to rep(-8, kMax-1)
if left unspecified.
- futilityCP
The conditional power-based futility bounds for the
primary trial.
- futilityTheta
The parameter value-based futility bounds for the
primary trial.
- spendingTime
The error spending time of the primary trial.
Defaults to missing, in which case it is assumed to be the same as
informationRates.
- MullerSchafer
Whether to use the Muller and Schafer (2001) method
for trial adaptation.
- MNew
Number of active treatment arms in the secondary trial.
- selected
The indices of the selected active treatment arms for
the secondary trial.
- rNew
Randomization ratio of each active arm to the common control
in the secondary trial.
- kNew
The number of looks of the secondary trial.
- informationRatesNew
The spacing of looks of the secondary trial.
- efficacyStoppingNew
The indicators of whether efficacy stopping is
allowed at each look of the secondary trial. Defaults to TRUE
if left unspecified.
- futilityStoppingNew
The indicators of whether futility stopping is
allowed at each look of the secondary trial. Defaults to TRUE
if left unspecified.
- typeAlphaSpendingNew
The type of alpha spending for the secondary
trial. One of the following:
"OF" for O'Brien-Fleming boundaries,
"sfOF" for O'Brien-Fleming type spending function,
"sfP" for Pocock type spending function,
"sfKD" for Kim & DeMets spending function,
"sfHSD" for Hwang, Shi & DeCani spending function, and
"none" for no early efficacy stopping.
Defaults to "sfOF".
- parameterAlphaSpendingNew
The parameter value of alpha spending
for the secondary trial. Corresponds to
\(\rho\) for "sfKD", and \(\gamma\) for "sfHSD".
- futilityBoundsInt
The futility boundaries on the max-z statistic
scale for new stages of the integrated trial.
- futilityCPInt
The conditional power-based futility bounds for
new stages of the integrated trial.
- futilityThetaInt
The parameter value-based futility bounds for the
new stages of the integrated trial.
- typeBetaSpendingNew
The type of beta spending for the secondary
trial. One of the following:
"sfOF" for O'Brien-Fleming type spending function,
"sfP" for Pocock type spending function,
"sfKD" for Kim & DeMets spending function,
"sfHSD" for Hwang, Shi & DeCani spending function,
"user" for user defined spending, and
"none" for no early futility stopping.
Defaults to "none".
- parameterBetaSpendingNew
The parameter value of beta spending
for the secondary trial. Corresponds to \(\rho\) for "sfKD",
and \(\gamma\) for "sfHSD".
- userBetaSpendingNew
The user-defined cumulative beta spending.
Represents the cumulative beta spent up to each stage of the
secondary trial.
- spendingTimeNew
The error spending time of the secondary trial.
Defaults to missing, in which case it is assumed to be the same as
informationRatesNew.
- nthreads
The number of threads to use (0 leaves the
RcppParallel setting unchanged).