| adaptDesign_seamless | R Documentation |
Calculates the conditional power for specified incremental information, given the interim results, parameter value, data-dependent changes in the error spending function, and the number and spacing of interim looks. Conversely, calculates the incremental information required to attain a specified conditional power, given the interim results, parameter value, data-dependent changes in the error spending function, and the number and spacing of interim looks.
adaptDesign_seamless(
betaNew = NA_real_,
INew = NA_real_,
M = NA_integer_,
r = 1,
corr_known = TRUE,
L = NA_integer_,
zL = NA_real_,
theta = NA_real_,
IMax = NA_real_,
K = NA_integer_,
informationRates = NA_real_,
efficacyStopping = NA_integer_,
futilityStopping = NA_integer_,
criticalValues = NULL,
alpha = 0.025,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA_real_,
userAlphaSpending = NA_real_,
futilityBounds = NULL,
futilityCP = NULL,
futilityTheta = NULL,
spendingTime = NA_real_,
MullerSchafer = FALSE,
kNew = NA_integer_,
informationRatesNew = NA_real_,
efficacyStoppingNew = NA_integer_,
futilityStoppingNew = NA_integer_,
typeAlphaSpendingNew = "sfOF",
parameterAlphaSpendingNew = NA_real_,
futilityBoundsInt = NULL,
futilityCPInt = NULL,
futilityThetaInt = NULL,
typeBetaSpendingNew = "none",
parameterBetaSpendingNew = NA_real_,
userBetaSpendingNew = NA_real_,
spendingTimeNew = NA_real_
)
betaNew |
The type II error for the secondary trial. |
INew |
The maximum information for the active arm versus the common
control in the secondary trial. Either
|
M |
Number of active treatment arms in Phase 2. |
r |
Randomization ratio of each active arm to the common control in Phase 2. |
corr_known |
Logical. If |
L |
The interim adaptation look in Phase 3. |
zL |
The z-test statistic at the interim adaptation look of Phase 3. |
theta |
The assumed treatment effect for the selected arm versus the common control. |
IMax |
Maximum information for the active arm versus the common control for the original trial. Must be provided. |
K |
Number of sequential looks in Phase 3. |
informationRates |
A numeric vector of information rates fixed
before the trial. If unspecified, defaults to |
efficacyStopping |
Indicators of whether efficacy stopping is
allowed at each stage of the primary trial. Defaults to |
futilityStopping |
Indicators of whether futility stopping is
allowed at each stage of the primary trial. Defaults to |
criticalValues |
The upper boundaries on the max z-test statistic scale for Phase 2 and the z-test statistics for the selected arm in Phase 3 for the primary trial. If missing, boundaries will be computed based on the specified alpha spending function. |
alpha |
The significance level of the primary trial. Defaults to 0.025. |
typeAlphaSpending |
The type of alpha spending for the primary
trial. One of the following:
|
parameterAlphaSpending |
The parameter value of alpha spending
for the primary trial. Corresponds to |
userAlphaSpending |
The user-defined alpha spending for the primary trial. Represents the cumulative alpha spent up to each stage. |
futilityBounds |
The lower boundaries on the max-z statistic scale
at end of phase 2 and the z-test statistic scale in phase 3
for futility stopping for the primary trial. Defaults to
|
futilityCP |
The conditional power-based futility bounds for the primary trial. |
futilityTheta |
The parameter value-based futility bounds for the primary trial. |
spendingTime |
The error spending time of the primary trial.
Defaults to missing, in which case it is assumed to be the same as
|
MullerSchafer |
Whether to use the Muller and Schafer (2001) method for trial adaptation. |
kNew |
The number of looks of the secondary trial. |
informationRatesNew |
The spacing of looks of the secondary trial. |
efficacyStoppingNew |
The indicators of whether efficacy stopping is
allowed at each look of the secondary trial. Defaults to |
futilityStoppingNew |
The indicators of whether futility stopping is
allowed at each look of the secondary trial. Defaults to |
typeAlphaSpendingNew |
The type of alpha spending for the secondary
trial. One of the following:
|
parameterAlphaSpendingNew |
The parameter value of alpha spending
for the secondary trial. Corresponds to |
futilityBoundsInt |
The futility boundaries on the z statistic scale for new stages of the integrated trial. |
futilityCPInt |
The conditional power-based futility bounds for new stages of the integrated trial. |
futilityThetaInt |
The parameter value-based futility bounds for the new stages of the integrated trial. |
typeBetaSpendingNew |
The type of beta spending for the secondary
trial. One of the following:
|
parameterBetaSpendingNew |
The parameter value of beta spending
for the secondary trial. Corresponds to |
userBetaSpendingNew |
The user-defined cumulative beta spending. Represents the cumulative beta spent up to each stage of the secondary trial. |
spendingTimeNew |
The error spending time of the secondary trial.
Defaults to missing, in which case it is assumed to be the same as
|
An adaptDesign_seamless object with three list components:
primaryTrial: A list of selected information for the primary
trial, including M, r, corr_known, K,
L, zL, theta, maxInformation, kMax,
informationRates, efficacyBounds, futilityBounds,
information, alpha, conditionalAlpha,
conditionalPower, and MullerSchafer.
secondaryTrial: A list of selected information for the seconary
trial, including overallReject, alpha, kMax,
maxInformation, informationRates, efficacyBounds,
futilityBounds, cumulativeRejection,
cumulativeFutility, cumulativeAlphaSpent,
information, typeAlphaSpending,
parameterAlphaSpending, typeBetaSpending,
parameterBetaSpending, userBetaSpending, and
spendingTime.
integratedTrial: A list of selected information for the integrated
trial, including M, r, corr_known, K,
L, zL, theta, maxInformation, kMax,
informationRates, efficacyBounds, futilityBounds,
and information.
Kaifeng Lu, kaifenglu@gmail.com
Ping Gao, Yingqiu Li. Adaptive two-stage seamless sequential design for clinical trials. Journal of Biopharmaceutical Statistics, 2025, 35(4), 565-587.
getDesign_seamless
(des1 <- adaptDesign_seamless(
betaNew = 0.1, M = 2, r = 1, corr_known = FALSE,
L = 1, zL = -log(0.67) * sqrt(80 / 4), theta = -log(0.691),
IMax = 120 / 4, K = 2, informationRates = c(1/3, 2/3, 1),
alpha = 0.025, typeAlphaSpending = "OF", kNew = 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.