Obtains the density of a truncated piecewise exponential distribution.
Arguments
- q
The vector of quantiles.
- piecewiseSurvivalTime
A vector that specifies the starting time of piecewise exponential survival time intervals. Must start with 0, e.g.,
c(0, 6)breaks the time axis into 2 event intervals: \([0, 6)\) and \([6, \infty)\). Defaults to 0 for exponential distribution.- lambda
A vector of hazard rates for the event. One for each analysis time interval.
- lowerBound
The left truncation time point for the survival time. Defaults to 0 for no truncation.
- log.d
Logical; if TRUE, densities d are given as log(d).
Author
Kaifeng Lu, kaifenglu@gmail.com