fDefaultWgtmat: Default Weight Matrix for All Intersection Hypotheses

View source: R/RcppExports.R

fDefaultWgtmatR Documentation

Default Weight Matrix for All Intersection Hypotheses

Description

Obtains the default weight matrix for all intersection hypotheses, assigning equal weights to the elementary hypotheses within each intersection hypothesis.

Usage

fDefaultWgtmat(m)

Arguments

m

The number of elementary hypotheses.

Value

A list with the following components:

  • inthyp: The indicator matrix for the intersection hypotheses.

  • wgtmat: The default weight matrix for the elementary hypotheses.

Author(s)

Kaifeng Lu, kaifenglu@gmail.com

Examples


fDefaultWgtmat(3)


lrstat documentation built on Aug. 25, 2026, 5:07 p.m.