| fDefaultWgtmat | R Documentation |
Obtains the default weight matrix for all intersection hypotheses, assigning equal weights to the elementary hypotheses within each intersection hypothesis.
fDefaultWgtmat(m)
m |
The number of elementary hypotheses. |
A list with the following components:
inthyp: The indicator matrix for the intersection hypotheses.
wgtmat: The default weight matrix for the elementary hypotheses.
Kaifeng Lu, kaifenglu@gmail.com
fDefaultWgtmat(3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.