Learn R Programming

lrstat (version 0.3.3)

fDefaultWgtmat: Default Weight Matrix for All Intersection Hypotheses

Description

Obtains the default weight matrix for all intersection hypotheses, assigning equal weights to the elementary hypotheses within each intersection hypothesis.

Usage

fDefaultWgtmat(m)

Value

A list with the following components:

  • inthyp: The indicator matrix for the intersection hypotheses.

  • wgtmat: The default weight matrix for the elementary hypotheses.

Arguments

m

The number of elementary hypotheses.

Author

Kaifeng Lu, kaifenglu@gmail.com

Examples

Run this code

fDefaultWgtmat(3)

Run the code above in your browser using DataLab