| fadjpbon | R Documentation |
Obtains the adjusted p-values for graphical approaches using weighted Bonferroni tests.
fadjpbon(p, wgtmat = NULL)
p |
The raw p-values for elementary hypotheses. |
wgtmat |
A list containing the weight matrix and the indicator matrix
for intersection hypotheses. If |
A list with the following components:
inthyp: The indicator matrix for the intersection hypotheses.
pinter: The local p-values for the intersection hypotheses.
padj: The adjusted p-values for the elementary hypotheses.
Kaifeng Lu, kaifenglu@gmail.com
Frank Bretz, Willi Maurer, Werner Brannath and Martin Posch. A graphical approach to sequentially rejective multiple test procedures. Statistics in Medicine. 2009; 28:586-604.
pvalues <- matrix(c(0.01,0.005,0.015,0.022, 0.02,0.015,0.010,0.023),
nrow=2, ncol=4, byrow=TRUE)
w <- c(0.5,0.5,0,0)
G <- matrix(c(0,0,1,0,0,0,0,1,0,1,0,0,1,0,0,0),
nrow=4, ncol=4, byrow=TRUE)
wgtmat <- fwgtmat(w,G)
fadjpbon(pvalues, wgtmat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.