Learn R Programming

lrstat (version 0.3.3)

fadjpsim: Adjusted p-Values for Simes-Based Graphical Approaches

Description

Obtains the adjusted p-values for graphical approaches using weighted Simes tests.

Usage

fadjpsim(p, wgtmat = NULL, family = NULL)

Value

A list with the following components:

  • inthyp: The indicator matrix for the intersection hypotheses.

  • pinter: The local p-values for the intersection hypotheses.

  • padj: The adjusted p-values for the elementary hypotheses.

Arguments

p

The raw p-values for elementary hypotheses.

wgtmat

A list containing the weight matrix and the indicator matrix for intersection hypotheses. If NULL, equal weights are assigned within each intersection hypothesis.

family

The matrix of family indicators for elementary hypotheses. Defaults to one family containing all elementary hypotheses.

Author

Kaifeng Lu, kaifenglu@gmail.com

References

Frank Bretz, Martin Posch, Ekkehard Glimm, Florian Klinglmueller, Willi Maurer, and Kornelius Rohmeyer. Graphical approach for multiple comparison procedures using weighted Bonferroni, Simes, or parameter tests. Biometrical Journal. 2011; 53:894-913.

Kaifeng Lu. Graphical approaches using a Bonferroni mixture of weighted Simes tests. Statistics in Medicine. 2016; 35:4041-4055.

Examples

Run this code

pvalues <- matrix(c(0.01,0.005,0.015,0.022, 0.02,0.015,0.010,0.023),
                  nrow=2, ncol=4, byrow=TRUE)
w <- c(0.5,0.5,0,0)
G <- matrix(c(0,0,1,0,0,0,0,1,0,1,0,0,1,0,0,0),
            nrow=4, ncol=4, byrow=TRUE)
wgtmat <- fwgtmat(w,G)

family <- matrix(c(1,1,0,0,0,0,1,1), nrow=2, ncol=4, byrow=TRUE)
fadjpsim(pvalues, wgtmat, family)

Run the code above in your browser using DataLab