finthyp: Indicator Matrix for All Intersection Hypotheses

View source: R/multiplicity.R

finthypR Documentation

Indicator Matrix for All Intersection Hypotheses

Description

Obtains the indicator matrix for all intersection hypotheses formed from a given number of elementary hypotheses, matching the row order used by fwgtmat and fDefaultWgtmat.

Usage

finthyp(m)

Arguments

m

The number of elementary hypotheses.

Value

The (2^m-1) \times m indicator matrix for the intersection hypotheses, with row 1 the global intersection (all hypotheses active) and the last row the singleton {m}.

Author(s)

Kaifeng Lu, kaifenglu@gmail.com

Examples


finthyp(3)


lrstat documentation built on Aug. 25, 2026, 5:07 p.m.