Learn R Programming

lrstat (version 0.3.3)

finthyp: Indicator Matrix for All Intersection Hypotheses

Description

Obtains the indicator matrix for all intersection hypotheses formed from a given number of elementary hypotheses, matching the row order used by fwgtmat and fDefaultWgtmat.

Usage

finthyp(m)

Value

The \((2^m-1) \times m\) indicator matrix for the intersection hypotheses, with row 1 the global intersection (all hypotheses active) and the last row the singleton {m}.

Arguments

m

The number of elementary hypotheses.

Author

Kaifeng Lu, kaifenglu@gmail.com

Examples

Run this code

finthyp(3)

Run the code above in your browser using DataLab