| fseqbon | R Documentation |
Obtains the test results for group sequential trials using graphical approaches based on weighted Bonferroni tests.
fseqbon(
w,
G,
alpha = 0.025,
kMax,
typeAlphaSpending = NULL,
parameterAlphaSpending = NULL,
maxInformation = NULL,
incidenceMatrix = NULL,
k1,
p,
information,
spendingTime = NULL,
nthreads = 0
)
w |
The vector of initial weights for elementary hypotheses. |
G |
The initial transition matrix. |
alpha |
The significance level. Defaults to 0.025. |
kMax |
The maximum number of stages. |
typeAlphaSpending |
The vector of alpha spending functions for
the hypotheses. Each element is one of the following:
|
parameterAlphaSpending |
The vector of parameter values for the
alpha spending functions for the hypotheses. Each element corresponds
to the value of |
maxInformation |
The vector of target maximum information for each hypothesis. Defaults to a vector of 1s if not provided. |
incidenceMatrix |
The |
k1 |
The number of study looks at the interim analysis. |
p |
The matrix of raw p-values for each hypothesis by study look. |
information |
The matrix of observed information for each hypothesis by study look. |
spendingTime |
The spending time for alpha spending by study look.
If not provided, it is the same as |
nthreads |
The number of threads to use in simulations (0 means the default RcppParallel behavior). |
A vector to indicate the first look the specific hypothesis is rejected (0 if the hypothesis is not rejected).
Kaifeng Lu, kaifenglu@gmail.com
Willi Maurer and Frank Bretz. Multiple testing in group sequential trials using graphical approaches. Statistics in Biopharmaceutical Research. 2013; 5:311-320.
# Case study from Maurer & Bretz (2013)
fseqbon(
w = c(0.5, 0.5, 0, 0),
G = matrix(c(0, 0.5, 0.5, 0, 0.5, 0, 0, 0.5,
0, 1, 0, 0, 1, 0, 0, 0),
nrow=4, ncol=4, byrow=TRUE),
alpha = 0.025,
kMax = 3,
typeAlphaSpending = rep("sfOF", 4),
maxInformation = rep(1, 4),
k1 = 2,
p = matrix(c(0.0062, 0.017, 0.009, 0.13,
0.0002, 0.0035, 0.002, 0.06),
nrow=2, ncol=4, byrow=TRUE),
information = matrix(c(rep(1/3, 4), rep(2/3, 4)),
nrow=2, ncol=4, byrow=TRUE),
nthreads = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.