Adjusted p-Values for Stepwise Testing Procedures for Two Sequences
Source:R/multiplicity.R
fstp2seq.RdObtains the adjusted p-values for the stepwise gatekeeping procedures for multiplicity problems involving two sequences of hypotheses.
Arguments
- p
The raw p-values for elementary hypotheses.
- gamma
The truncation parameters for each family. The truncation parameter for the last family is automatically set to 1.
- test
The component multiple testing procedure. It is either "Holm" or "Hochberg", and it defaults to "Hochberg".
- retest
Whether to allow retesting. It defaults to
TRUE.
Author
Kaifeng Lu, kaifenglu@gmail.com