| getBound | R Documentation |
Obtains the efficacy stopping boundaries for a group sequential design.
getBound(
k = NA_integer_,
informationRates = NA_real_,
alpha = 0.025,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA_real_,
userAlphaSpending = NA_real_,
spendingTime = NA_real_,
efficacyStopping = NA_integer_
)
k |
Look number for the current analysis. |
informationRates |
Information rates up to the current look. Must be increasing and less than or equal to 1. |
alpha |
The significance level. Defaults to 0.025. |
typeAlphaSpending |
The type of alpha spending. One of the following:
|
parameterAlphaSpending |
The parameter value for the alpha spending.
Corresponds to |
userAlphaSpending |
The user defined alpha spending. Cumulative alpha spent up to each stage. |
spendingTime |
A vector of length |
efficacyStopping |
Indicators of whether efficacy stopping is allowed
at each stage. Defaults to |
If typeAlphaSpending is "OF", "P", "WT", or
"none", then informationRates, efficacyStopping,
and spendingTime must be of full length kMax, and
informationRates and spendingTime must end with 1.
A numeric vector of critical values up to the current look.
Kaifeng Lu, kaifenglu@gmail.com
getBound(k = 2, informationRates = c(0.5,1),
alpha = 0.025, typeAlphaSpending = "sfOF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.