Obtains the efficacy stopping boundaries for a group sequential design.
getBound(
k = NA_integer_,
informationRates = NA_real_,
alpha = 0.025,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA_real_,
userAlphaSpending = NA_real_,
spendingTime = NA_real_,
efficacyStopping = NA_integer_
)A numeric vector of critical values up to the current look.
Look number for the current analysis.
Information rates up to the current look. Must be increasing and less than or equal to 1.
The significance level. Defaults to 0.025.
The type of alpha spending. One of the following:
"OF" for O'Brien-Fleming boundaries,
"P" for Pocock boundaries,
"WT" for Wang & Tsiatis boundaries,
"sfOF" for O'Brien-Fleming type spending function,
"sfP" for Pocock type spending function,
"sfKD" for Kim & DeMets spending function,
"sfHSD" for Hwang, Shi & DeCani spending function,
"user" for user defined spending, and
"none" for no early efficacy stopping.
Defaults to "sfOF".
The parameter value for the alpha spending.
Corresponds to \(\Delta\) for "WT", \(\rho\) for "sfKD",
and \(\gamma\) for "sfHSD".
The user defined alpha spending. Cumulative alpha spent up to each stage.
A vector of length k for the error spending
time at each analysis. Must be increasing and less than or equal to 1.
Defaults to missing, in which case, it is the same as
informationRates.
Indicators of whether efficacy stopping is allowed
at each stage. Defaults to TRUE if left unspecified.
Kaifeng Lu, kaifenglu@gmail.com
If typeAlphaSpending is "OF", "P", "WT", or
"none", then informationRates, efficacyStopping,
and spendingTime must be of full length kMax, and
informationRates and spendingTime must end with 1.
getBound(k = 2, informationRates = c(0.5,1),
alpha = 0.025, typeAlphaSpending = "sfOF")
Run the code above in your browser using DataLab