| getBound_mams | R Documentation |
Calculates the efficacy stopping boundaries for a multi-arm multi-stage design.
getBound_mams(
M = NA_integer_,
r = 1,
corr_known = TRUE,
k = NA_integer_,
informationRates = NA_real_,
alpha = 0.025,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA_real_,
userAlphaSpending = NA_real_,
spendingTime = NA_real_,
efficacyStopping = NA_integer_
)
M |
Number of active treatment arms. |
r |
Randomization ratio of each active arm to the common control. |
corr_known |
Logical. If |
k |
The index of the current look. |
informationRates |
A numeric vector of information rates up to the
current look. Values must be strictly increasing and |
alpha |
The significance level. Defaults to 0.025. |
typeAlphaSpending |
The type of alpha spending. One of the following:
|
parameterAlphaSpending |
The parameter value for the alpha spending.
Corresponds to |
userAlphaSpending |
The user defined alpha spending. Cumulative alpha spent up to each stage. |
spendingTime |
A numeric vector of length |
efficacyStopping |
Indicators of whether efficacy stopping is allowed
at each stage. Defaults to |
The function determines critical values by solving for the boundary that satisfies the alpha-spending requirement.
If typeAlphaSpending is "OF", "P", "WT", or
"none", then informationRates, efficacyStopping,
and spendingTime must be of full length kMax, and
informationRates and spendingTime must end with 1.
A numeric vector of length k containing the critical
values (on the standard normal Z-scale) for each analysis up to the
current look.
Kaifeng Lu, kaifenglu@gmail.com
Ping Gao, Yingqiu Li. Adaptive multiple comparison sequential design (AMCSD) for clinical trials. Journal of Biopharmaceutical Statistics, 2024, 34(3), 424-440.
# Determine O'Brien-Fleming boundaries for a TSSSD with
# 2 active arms and 3 looks.
getBound_mams(M = 2, k = 3, informationRates = seq(1, 3)/3,
alpha = 0.025, typeAlphaSpending = "OF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.