| getBound_seamless | R Documentation |
Calculates the efficacy stopping boundaries for a phase 2/3 seamless design, accounting for the selection of the best arm at the end of Phase 2 and sequential testing in Phase 3.
getBound_seamless(
M = NA_integer_,
r = 1,
corr_known = TRUE,
k = NA_integer_,
informationRates = NA_real_,
alpha = 0.025,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA_real_,
userAlphaSpending = NA_real_,
spendingTime = NA_real_,
efficacyStopping = NA_integer_
)
M |
Number of active treatment arms in Phase 2. |
r |
Randomization ratio of each active arm to the common control in Phase 2. |
corr_known |
Logical. If |
k |
The index of the current look in Phase 3. |
informationRates |
A numeric vector of information rates up to the
current look. Values must be strictly increasing and |
alpha |
The significance level. Defaults to 0.025. |
typeAlphaSpending |
The type of alpha spending. One of the following:
|
parameterAlphaSpending |
The parameter value for the alpha spending.
Corresponds to |
userAlphaSpending |
The user defined alpha spending. Cumulative alpha spent up to each stage. |
spendingTime |
A numeric vector of length |
efficacyStopping |
Indicators of whether efficacy stopping is allowed
at each stage. Defaults to |
The function determines critical values by solving for the boundary that satisfies the alpha-spending requirement, given the selection of the "best" arm at the end of Phase 2.
If typeAlphaSpending is "OF", "P", "WT", or
"none", then informationRates, efficacyStopping,
and spendingTime must be of full length kMax, and
informationRates and spendingTime must end with 1.
A numeric vector of length k + 1 containing the critical
values (on the standard normal Z-scale) for each analysis up to the
current look.
Kaifeng Lu, kaifenglu@gmail.com
Ping Gao, Yingqiu Li. Adaptive two-stage seamless sequential design for clinical trials. Journal of Biopharmaceutical Statistics, 2025, 35(4), 565-587.
# Determine O'Brien-Fleming boundaries for a seamless design with
# 2 active arms in Phase 2 and 2 looks in Phase 3 (3 looks total).
getBound_seamless(M = 2, k = 2, informationRates = seq(1, 3)/3,
alpha = 0.025, typeAlphaSpending = "OF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.