| getCI_mams | R Documentation |
Obtains the p-value, conservative point estimate, and confidence interval after the end of a multi-arm multi-stage trial.
getCI_mams(
M = NA_integer_,
r = 1,
corr_known = TRUE,
L = NA_integer_,
zL = NA_real_,
IMax = NA_real_,
informationRates = NA_real_,
efficacyStopping = NA_integer_,
criticalValues = NULL,
alpha = 0.025,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA_real_,
spendingTime = NA_real_
)
M |
Number of active treatment arms. |
r |
Randomization ratio of each active arm to the common control. |
corr_known |
Logical. If |
L |
The termination look. |
zL |
The vector of z-test statistics at the termination look. |
IMax |
Maximum information for any active arm versus the common control. |
informationRates |
The information rates up to look |
efficacyStopping |
Indicators of whether efficacy stopping is
allowed at each stage up to look |
criticalValues |
The matrix of by-level upper boundaries on the
max z-test statistic scale for efficacy stopping up to look |
alpha |
The significance level. Defaults to 0.025. |
typeAlphaSpending |
The type of alpha spending for the trial.
One of the following:
|
parameterAlphaSpending |
The parameter value for the alpha spending.
Corresponds to |
spendingTime |
The error spending time up to look |
If typeAlphaSpending is "OF", "P", "WT", or
"none", then informationRates, efficacyStopping,
and spendingTime must be of full length kMax, and
informationRates and spendingTime must end with 1.
A data frame with the following components:
level: Number of individual hypotheses considered for multiplicity.
index: The treatment arm with max Z among the active arms.
pvalue: p-value for rejecting the null hypothesis.
thetahat: Point estimate of the parameter.
cilevel: Confidence interval level.
lower: Lower bound of confidence interval.
upper: Upper bound of confidence interval.
Kaifeng Lu, kaifenglu@gmail.com
Ping Gao, Yingqiu Li. Adaptive multiple comparison sequential design (AMCSD) for clinical trials. Journal of Biopharmaceutical Statistics, 2024, 34(3), 424-440.
getCI_mams(
L = 2, zL = c(2.075, 2.264),
M = 2, r = 1, corr_known = FALSE,
IMax = 300 / 4, informationRates = c(1/2, 1),
alpha = 0.025, typeAlphaSpending = "sfOF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.