| getCI_seamless | R Documentation |
Obtains the p-value, point estimate, and confidence interval after the end of a phase 2/3 seamless trial.
getCI_seamless(
M = NA_integer_,
r = 1,
corr_known = TRUE,
L = NA_integer_,
zL = NA_real_,
IMax = NA_real_,
informationRates = NA_real_,
efficacyStopping = NA_integer_,
criticalValues = NA_real_,
alpha = 0.025,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA_real_,
spendingTime = NA_real_
)
M |
Number of active treatment arms in Phase 2. |
r |
Randomization ratio of each active arm to the common control in Phase 2. |
corr_known |
Logical. If |
L |
The termination look in Phase 3. |
zL |
The z-test statistic at the termination look. |
IMax |
Maximum information for any active arm versus the common control. |
informationRates |
The information rates up to look |
efficacyStopping |
Indicators of whether efficacy stopping is
allowed at each stage up to look |
criticalValues |
The upper boundaries on the max z-test statistic
scale for Phase 2 and the z-test statistics for the selected arm
in Phase 3 up to look |
alpha |
The significance level. Defaults to 0.025. |
typeAlphaSpending |
The type of alpha spending for the trial.
One of the following:
|
parameterAlphaSpending |
The parameter value for the alpha spending.
Corresponds to |
spendingTime |
The error spending time up to look |
If typeAlphaSpending is "OF", "P", "WT", or
"none", then informationRates, efficacyStopping,
and spendingTime must be of full length K + 1, and
informationRates and spendingTime must end with 1.
A data frame with the following components:
pvalue: p-value for rejecting the null hypothesis.
thetahat: Point estimate of the parameter.
cilevel: Confidence interval level.
lower: Lower bound of confidence interval.
upper: Upper bound of confidence interval.
Kaifeng Lu, kaifenglu@gmail.com
Ping Gao, Yingqiu Li. Adaptive two-stage seamless sequential design for clinical trials. Journal of Biopharmaceutical Statistics, 2025, 35(4), 565-587.
getCI_seamless(
L = 2, zL = 2.075,
M = 2, r = 1, corr_known = FALSE,
IMax = 300 / 4, informationRates = c(1/3, 2/3, 1),
alpha = 0.025, typeAlphaSpending = "sfOF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.