| getNeventsFromHazardRatio | R Documentation |
Obtains the required number of events given the hazard ratios under the null and alternative hypotheses for a group sequential design.
getNeventsFromHazardRatio(
beta = 0.2,
kMax = 1L,
informationRates = NA_real_,
efficacyStopping = NA_integer_,
futilityStopping = NA_integer_,
criticalValues = NULL,
alpha = 0.025,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA_real_,
userAlphaSpending = NA_real_,
futilityBounds = NULL,
futilityCP = NULL,
futilityHR = NULL,
typeBetaSpending = "none",
parameterBetaSpending = NA_real_,
userBetaSpending = NA_real_,
spendingTime = NA_real_,
hazardRatioH0 = 1,
hazardRatio = NA_real_,
allocationRatioPlanned = 1,
rounding = TRUE
)
beta |
Type II error. Defaults to 0.2. |
kMax |
The maximum number of stages. |
informationRates |
The information rates in terms of number of
events. Fixed prior to the trial. Defaults to |
efficacyStopping |
Indicators of whether efficacy stopping is allowed
at each stage. Defaults to |
futilityStopping |
Indicators of whether futility stopping is allowed
at each stage. Defaults to |
criticalValues |
Upper boundaries on the z-test statistic scale for stopping for efficacy. |
alpha |
The significance level. Defaults to 0.025. |
typeAlphaSpending |
The type of alpha spending. One of the following:
|
parameterAlphaSpending |
The parameter value for the alpha spending.
Corresponds to |
userAlphaSpending |
The user defined alpha spending. Cumulative alpha spent up to each stage. |
futilityBounds |
Lower boundaries on the z-test statistic scale
for stopping for futility at stages |
futilityCP |
A vector of length |
futilityHR |
A vector of length |
typeBetaSpending |
The type of beta spending. One of the following:
|
parameterBetaSpending |
The parameter value for the beta spending.
Corresponds to |
userBetaSpending |
The user defined beta spending. Cumulative beta spent up to each stage. |
spendingTime |
A vector of length |
hazardRatioH0 |
Hazard ratio under the null hypothesis for the active treatment versus control. Defaults to 1 for superiority test. |
hazardRatio |
Hazard ratio under the alternative hypothesis for the active treatment versus control. |
allocationRatioPlanned |
Allocation ratio for the active treatment versus control. Defaults to 1 for equal randomization. |
rounding |
Whether to round up the number of events. Defaults to 1 for rounding. |
The required number of events.
Kaifeng Lu, kaifenglu@gmail.com
getNeventsFromHazardRatio(
beta = 0.2, kMax = 2,
informationRates = c(0.5,1),
alpha = 0.025, typeAlphaSpending = "sfOF",
typeBetaSpending = "sfP",
hazardRatio = 0.673)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.