Miettinen-Nurminen Score Confidence Interval for Two-Sample Rate Difference
Source:R/RcppExports.R
mnRateDiffCI.RdObtains the Miettinen-Nurminen score confidence interval for two-sample rate difference possibly with stratification.
Value
A list with two components:
dataA data frame containing the input exposure and number of events for each treatment group. It has the following variables:t1: The exposure for the active treatment group.y1: The number of events for the active treatment group.t2: The exposure for the control group.y2: The number of events for the control group.
estimates: A data frame containing the point estimate and confidence interval for rate difference. It has the following variables:scale: The scale of treatment effect.estimate: The point estimate.lower: The lower limit of the confidence interval.upper: The upper limit of the confidence interval.cilevel: The confidence interval level.
Author
Kaifeng Lu, kaifenglu@gmail.com