Miettinen-Nurminen Score Confidence Interval for Two-Sample Risk Ratio
Source:R/RcppExports.R
mnRiskRatioCI.RdObtains the Miettinen-Nurminen score confidence interval for two-sample risk ratio possibly with stratification.
Value
A list with two components:
dataA data frame containing the input sample size and number of responses for each treatment group. It has the following variables:n1: The sample size for the active treatment group.y1: The number of responses for the active treatment group.n2: The sample size for the control group.y2: The number of responses for the control group.
estimates: A data frame containing the point estimate and confidence interval for risk ratio. It has the following variables:scale: The scale of treatment effect.estimate: The point estimate.lower: The lower limit of the confidence interval.upper: The upper limit of the confidence interval.cilevel: The confidence interval level.
Author
Kaifeng Lu, kaifenglu@gmail.com