| mtpwexp | R Documentation |
Obtains the mean and variance from a truncated piecewise exponential distribution.
mtpwexp(piecewiseSurvivalTime = 0L, lambda = NA_real_, lowerBound = 0)
piecewiseSurvivalTime |
A vector that specifies the starting time of
piecewise exponential survival time intervals. Must start with 0, e.g.,
|
lambda |
A vector of hazard rates for the event. One for each analysis time interval. |
lowerBound |
The left truncation time point for the survival time. Defaults to 0 for no truncation. |
A list with two components, one for the mean, and the other for the variance of the truncated piecewise exponential distribution.
Kaifeng Lu, kaifenglu@gmail.com
mtpwexp(piecewiseSurvivalTime = c(0, 6, 9, 15),
lambda = c(0.025, 0.04, 0.015, 0.007))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.