Computes the cumulative distribution function (CDF) of the standard bivariate normal distribution with specified lower and upper integration limits and correlation coefficient.
Value
A numeric value representing the probability that a standard bivariate normal vector falls within the specified rectangular region.
Details
This function evaluates the probability
\(P(\code{lower[1]} < X < \code{upper[1]},
\code{lower[2]} < Y < \code{upper[2]})\) where
\((X, Y)\) follows a standard bivariate normal
distribution with correlation corr.
Author
Kaifeng Lu, kaifenglu@gmail.com