Generate line plots of observed and simulated paths of standardized score processes of a Cox model.
# S3 method for assess_phregr
plot(x, nsim = 20, ...)A list of ggplot2 objects for the line plots, one for each covariate.
An object of class assess_phregr.
The number of simulation samples used in the plot.
Ensures that all arguments starting from "..." are named.
Kaifeng Lu, kaifenglu@gmail.com