| print.lrsim_bmTrtSel | R Documentation |
Prints the summary statistics from simulation for a seamless phase II/III design that selects one dose at the end of phase II based on a short-term efficacy endpoint and a short-term toxicity endpoint, and compares the testing procedures available for the confirmatory analysis.
## S3 method for class 'lrsim_bmTrtSel'
print(x, ...)
x |
The lrsim_bmTrtSel object to print. |
... |
Ensures that all arguments starting from "..." are named. |
A tabular printout of the summary statistics from simulation runs.
Kaifeng Lu, kaifenglu@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.