Learn R Programming

lrstat (version 0.3.3)

print.lrsim_bmTrtSel: Print Simulation Results for Phase 2/3 Seamless Design with Biomarker-Based Treatment Selection

Description

Prints the summary statistics from simulation for a seamless phase II/III design that selects one dose at the end of phase II based on a short-term efficacy endpoint and a short-term toxicity endpoint, and compares the testing procedures available for the confirmatory analysis.

Usage

# S3 method for lrsim_bmTrtSel
print(x, ...)

Value

A tabular printout of the summary statistics from simulation runs.

Arguments

x

The lrsim_bmTrtSel object to print.

...

Ensures that all arguments starting from "..." are named.

Author

Kaifeng Lu, kaifenglu@gmail.com