Prints the summary statistics from simulation for a seamless phase II/III design that selects one dose at the end of phase II based on a short-term efficacy endpoint and a short-term toxicity endpoint, and compares the testing procedures available for the confirmatory analysis.
# S3 method for lrsim_bmTrtSel
print(x, ...)A tabular printout of the summary statistics from simulation runs.
The lrsim_bmTrtSel object to print.
Ensures that all arguments starting from "..." are named.
Kaifeng Lu, kaifenglu@gmail.com