| qmvnormr | R Documentation |
Computes the equicoordinate quantile q such that
P(X_1 \le q, X_2 \le q, \ldots, X_k \le q) = p for a multivariate
normal random vector X.
qmvnormr(
p,
mean = NULL,
sigma,
n0 = 1024,
n_max = 16384,
R = 8,
abseps = 1e-04,
releps = 0,
seed = 0,
parallel = TRUE,
nthreads = 0
)
p |
The probability level (cumulative probability). |
mean |
The mean vector. If |
sigma |
The covariance (or correlation) matrix of the distribution. |
n0 |
Initial number of samples per replication for the Monte Carlo integration. |
n_max |
Maximum number of samples allowed per replication. |
R |
Number of independent replications used to estimate the error. |
abseps |
Absolute error tolerance for the probability calculation. |
releps |
Relative error tolerance for the probability calculation. |
seed |
Random seed for reproducibility. If 0, a seed is generated from the computer clock. |
parallel |
Logical; if |
nthreads |
Number of threads for parallel execution. If 0, the default RcppParallel behavior is used. |
This function finds the value q using a root-finding algorithm
applied to the pmvnormr function. It solves for the value where
the multivariate normal cumulative distribution function equals the
target probability p.
A numeric value representing the calculated equicoordinate quantile.
Kaifeng Lu, kaifenglu@gmail.com
n <- 5
mean <- rep(0, n)
sigma <- matrix(0.5, n, n)
diag(sigma) <- 1
qmvnormr(0.5, mean = mean, sigma = sigma)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.