| remlRateRatio | R Documentation |
Obtains the restricted maximum likelihood estimates of individual proportions with specified rate ratio.
remlRateRatio(t1, y1, t2, y2, rateRatioH0 = 1)
t1 |
The exposure for the active treatment group. |
y1 |
The number of events for the active treatment group. |
t2 |
The exposure for the control group. |
y2 |
The number of events for the control group. |
rateRatioH0 |
The specified rate ratio. |
A vector of the restricted maximum likelihood estimates of the incidence rates for the two treatment groups.
Kaifeng Lu, kaifenglu@gmail.com
remlRateRatio(t1 = 10, y1 = 4, t2 = 20, y2 = 2, rateRatioH0 = 1.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.