powered by
Obtains the restricted maximum likelihood estimates of individual proportions with specified rate ratio.
remlRateRatio(t1, y1, t2, y2, rateRatioH0 = 1)
A vector of the restricted maximum likelihood estimates of the incidence rates for the two treatment groups.
The exposure for the active treatment group.
The number of events for the active treatment group.
The exposure for the control group.
The number of events for the control group.
The specified rate ratio.
Kaifeng Lu, kaifenglu@gmail.com
remlRateRatio(t1 = 10, y1 = 4, t2 = 20, y2 = 2, rateRatioH0 = 1.1)
Run the code above in your browser using DataLab