powered by
Obtains the restricted maximum likelihood estimates of individual proportions with specified risk difference.
remlRiskDiff(n1, y1, n2, y2, riskDiffH0 = 0)
A vector of the restricted maximum likelihood estimates of the response probabilities for the two treatment groups.
The sample size for the active treatment group.
The number of responses for the active treatment group.
The sample size for the control group.
The number of responses for the control group.
The specified risk difference.
Kaifeng Lu, kaifenglu@gmail.com
remlRiskDiff(n1 = 10, y1 = 4, n2 = 20, y2 = 0, riskDiffH0 = 0.1)
Run the code above in your browser using DataLab