| repeatedPValue | R Documentation |
Obtains the repeated p-values for a group sequential design.
repeatedPValue(
kMax,
typeAlphaSpending = "sfOF",
parameterAlphaSpending = NA,
maxInformation = 1,
p,
information,
spendingTime = NULL,
nthreads = 0
)
kMax |
The maximum number of stages. |
typeAlphaSpending |
The type of alpha spending. One of the following:
|
parameterAlphaSpending |
The parameter value for the alpha spending.
Corresponds to |
maxInformation |
The target maximum information. Defaults to 1,
in which case, |
p |
The raw p-values at look 1 to look |
information |
The observed information by look. It can be a matrix
with |
spendingTime |
The error spending time at each analysis, must be
increasing and less than or equal to 1. Defaults to |
nthreads |
The number of threads to use in simulations (0 means the default RcppParallel behavior). |
The repeated p-values at look 1 to look k.
Kaifeng Lu, kaifenglu@gmail.com
# Example 1: informationRates different from spendingTime
repeatedPValue(kMax = 3, typeAlphaSpending = "sfOF",
maxInformation = 800,
p = c(0.2, 0.15, 0.1),
information = c(529, 700, 800),
spendingTime = c(0.6271186, 0.8305085, 1))
# Example 2: Maurer & Bretz (2013), current look is not the last look
repeatedPValue(kMax = 3, typeAlphaSpending = "sfOF",
p = matrix(c(0.0062, 0.017,
0.009, 0.13,
0.0002, 0.0035,
0.002, 0.06),
nrow=4, ncol=2),
information = c(1/3, 2/3),
nthreads = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.