Random Number Generation Function of Truncated Piecewise Exponential Distribution
Source:R/utilities.R
rtpwexp.RdObtains random samples from a truncated piecewise exponential distribution.
Arguments
- n
The number of observations.
- piecewiseSurvivalTime
A vector that specifies the starting time of piecewise exponential survival time intervals. Must start with 0, e.g.,
c(0, 6)breaks the time axis into 2 event intervals: \([0, 6)\) and \([6, \infty)\). Defaults to 0 for exponential distribution.- lambda
A vector of hazard rates for the event. One for each analysis time interval.
- lowerBound
The left truncation time point for the survival time. Defaults to 0 for no truncation.
Author
Kaifeng Lu, kaifenglu@gmail.com