pi1: The assumed probability for the active treatment group.
pi2: The assumed probability for the control group.
allocationRatioPlanned: Allocation ratio for the active
treatment versus control.
Arguments
beta
The type II error.
pi1
The assumed probability for the active treatment group.
pi2
The assumed probability for the control group.
allocationRatioPlanned
Allocation ratio for the active treatment
versus control. Defaults to 1 for equal randomization.
alpha
The two-sided significance level. Defaults to 0.05.
max_n_search
The maximum sample size to search up to. If no
sample size up to this value satisfies the windowed power criterion,
an error is thrown.
window
The number of consecutive sample sizes that must all
satisfy the power criterion to confirm the found sample size.
This is to mitigate non-monotonicity of power in sample size for
the exact test.