Obtains the prior and posterior probabilities for Simon's Bayesian basket discovery trials.
Usage
simonBayesAnalysis(
nstrata = NA_integer_,
r = NA_real_,
n = NA_real_,
lambda = NA_real_,
gamma = NA_real_,
phi = NA_real_,
plo = NA_real_
)Arguments
- nstrata
The number of strata.
- r
The vector of number of responders across strata.
- n
The vector of number of subjects across strata.
- lambda
The prior probability that the drug activity is homogeneous across strata.
- gamma
The prior probability that the drug is active in a stratum.
- phi
The response probability for an active drug.
- plo
The response probability for an inactive drug.
Value
A list containing the following five components:
case: The matrix with each row corresponding to a combination of drug activity over strata represented by the columns.prior_case: The vector of joint prior probabilities for the stratum-specific response rates.prior_stratum: The vector of marginal prior probabilities for the stratum-specific response rates.post_case: The vector of joint posterior probabilities for the stratum-specific response rates.post_stratum: The vector of marginal posterior probabilities for the stratum-specific response rates.
Author
Kaifeng Lu, kaifenglu@gmail.com